@@ -49,24 +49,24 @@ inter.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
 # MMPC frontend.
 mmpc = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
     test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
-    strict = FALSE) {
+    strict = FALSE, undirected = TRUE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
     blacklist = blacklist, test = test, alpha = alpha, B = B,
     method = "mmpc", debug = debug, optimized = optimized,
-    strict = strict, undirected = TRUE)
+    strict = strict, undirected = undirected)
 
 }#MMPC
 
 # Semi-Interleaved HITON-PC.
 si.hiton.pc = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
     test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
-    strict = FALSE) {
+    strict = FALSE, undirected = TRUE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
     blacklist = blacklist, test = test, alpha = alpha, B = B,
     method = "si.hiton.pc", debug = debug, optimized = optimized,
-    strict = strict, undirected = TRUE)
+    strict = strict, undirected = undirected)
 
 }#MMPC
 
@@ -156,7 +156,7 @@ learn.mb = function(x, node, method, whitelist = NULL, blacklist = NULL,
 
 # Frontend for causal discovery learning algorithms.
 learn.nbr = function(x, node, method, whitelist = NULL, blacklist = NULL,
-    start = NULL, test = NULL, alpha = 0.05, B = NULL, debug = FALSE) {
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE) {
 
   nbr.backend(x, target = node, method = method, whitelist = whitelist,
     blacklist = blacklist, test = test, alpha = alpha, B = B, debug = debug)
