@@ -5,22 +5,23 @@
 #define ABSENT     0
 #define PRESENT    1
 #define FIXED      2
+#define IMMUTABLE  3
 
 #define UNCHANGED  0
 #define CHANGED    1
 
-static void scan_graph(int *a, SEXP nodes, int *nnodes,
+static void scan_graph(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel);
+static void mark_vstructures(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel);
+static void unmark_shielded(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel);
+static int prevent_cycles(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel);
+static int prevent_additional_vstructures(int *a, SEXP nodes, int nnodes,
     short int *collider, int debuglevel);
-static void mark_vstructures(int *a, SEXP nodes, int *nnodes,
-    short int *collider, int debuglevel);
-static void unmark_shielded(int *a, SEXP nodes, int *nnodes,
-    short int *collider, int debuglevel);
-static int prevent_cycles(int *a, SEXP nodes, int *nnodes,
-    short int *collider, int debuglevel);
-static int prevent_additional_vstructures(int *a, SEXP nodes,
-    int *nnodes, short int *collider, int debuglevel);
-static void renormalize_amat(int *a, int *nnodes);
-static SEXP amat2vstructs(int *a, SEXP nodes, int *nnodes, short int *collider);
+static void renormalize_amat(int *a, int nnodes);
+static SEXP amat2vstructs(int *a, SEXP nodes, int nnodes, short int *collider);
 
 /* return the v-structures present in the graph. */
 SEXP vstructures(SEXP arcs, SEXP nodes, SEXP return_arcs, SEXP moral, SEXP debug) {
@@ -39,14 +40,14 @@ SEXP amat, result;
   collider = Calloc1D(nnodes, sizeof(short int));
 
   /* STEP 1: scan the graph. */
-  scan_graph(a, nodes, &nnodes, collider, debuglevel);
+  scan_graph(a, nodes, nnodes, collider, debuglevel);
 
   /* STEP 2: all the arcs not part of a v-structure are now undirected. */
-  mark_vstructures(a, nodes, &nnodes, collider, debuglevel);
+  mark_vstructures(a, nodes, nnodes, collider, debuglevel);
 
   /* decide whether or not to keep moral v-structures (i.e. shielded colliders). */
   if (all_vstructs == 0)
-    unmark_shielded(a, nodes, &nnodes, collider, debuglevel);
+    unmark_shielded(a, nodes, nnodes, collider, debuglevel);
 
   /* remove all non-fixed arcs (including compelled ones). */
   for (i = 0; i < nnodes * nnodes; i++)
@@ -55,7 +56,7 @@ SEXP amat, result;
   if (*ret_arcs > 0)
     PROTECT(result = amat2arcs(amat, nodes));
   else
-    PROTECT(result = amat2vstructs(a, nodes, &nnodes, collider));
+    PROTECT(result = amat2vstructs(a, nodes, nnodes, collider));
 
   UNPROTECT(2);
 
@@ -65,12 +66,12 @@ SEXP amat, result;
 
 }/*VSTRUCTURES*/
 
-static SEXP amat2vstructs(int *a, SEXP nodes, int *nnodes, short int *collider) {
+static SEXP amat2vstructs(int *a, SEXP nodes, int nnodes, short int *collider) {
 
 int i = 0, j = 0, k = 0, nvstructs = 0, counter = 0, row = 0;
 SEXP result;
 
-  for (i = 0; i < *nnodes; i++) {
+  for (i = 0; i < nnodes; i++) {
 
     /* this is not a collider, nothing to do. */
     if (collider[i] == 0)
@@ -80,8 +81,8 @@ SEXP result;
     counter = 0;
 
     /* count the parents. */
-    for (j = 0; j < *nnodes; j++)
-      counter += a[CMC(j, i, *nnodes)];
+    for (j = 0; j < nnodes; j++)
+      counter += a[CMC(j, i, nnodes)];
 
     /* only arcs that are part of a v-structure are still present in the
      * adjacency matrix, so computing the number of v-structures is easy. */
@@ -94,23 +95,23 @@ SEXP result;
   /* allocate and the colnames. */
   setDimNames(result, R_NilValue, mkStringVec(3, "X", "Z", "Y"));
 
-  for (i = 0; i < *nnodes; i++) {
+  for (i = 0; i < nnodes; i++) {
 
     /* this is not a collider, nothing to do. */
     if (collider[i] == 0)
       continue;
 
-    for (j = 0; j < *nnodes; j++) {
+    for (j = 0; j < nnodes; j++) {
 
       /* this is no parent. */
-      if (a[CMC(j, i, *nnodes)] == 0)
+      if (a[CMC(j, i, nnodes)] == 0)
         continue;
 
       /* this is a parent, look for the other one. */
-      for (k = j + 1; k < *nnodes; k++) {
+      for (k = j + 1; k < nnodes; k++) {
 
         /* again this is no parent. */
-        if (a[CMC(k, i, *nnodes)] == 0)
+        if (a[CMC(k, i, nnodes)] == 0)
           continue;
 
         SET_STRING_ELT(result, CMC(row, 0, nvstructs), STRING_ELT(nodes, j));
@@ -176,9 +177,9 @@ SEXP wl, bl;
               (w[CMC(i, j, nnodes)] == PRESENT)) {
 
             if (debuglevel > 0)
-              Rprintf("* fixing arc %s -> %s from the whitelist.\n", NODE(i), NODE(j));
+              Rprintf("  > marking arc %s -> %s as immutable.\n", NODE(i), NODE(j));
 
-            a[CMC(i, j, nnodes)] = FIXED;
+            a[CMC(i, j, nnodes)] = IMMUTABLE;
 
           }/*THEN*/
 
@@ -188,7 +189,7 @@ SEXP wl, bl;
       UNPROTECT(1);
 
     }/*THEN*/
-        
+
     if (blacklist != R_NilValue) {
 
       PROTECT(bl = arcs2amat(blacklist, nodes));
@@ -203,9 +204,9 @@ SEXP wl, bl;
               (b[CMC(i, j, nnodes)] == ABSENT)) {
 
             if (debuglevel > 0)
-              Rprintf("* fixing arc %s -> %s from the blacklist.\n", NODE(i), NODE(j));
+              Rprintf("  > marking arc %s -> %s as immutable.\n", NODE(i), NODE(j));
 
-            a[CMC(i, j, nnodes)] = FIXED;
+            a[CMC(i, j, nnodes)] = IMMUTABLE;
 
           }/*THEN*/
 
@@ -238,31 +239,37 @@ SEXP amat;
   collider = Calloc1D(nnodes, sizeof(short int));
 
   /* STEP 1a: scan the graph. */
-  scan_graph(a, nodes, &nnodes, collider, debuglevel);
+  scan_graph(a, nodes, nnodes, collider, debuglevel);
 
   /* STEP 1b: fix arcs whose direction is determined by parametric assumptions
    * (the illegal argument works like a blacklist). */
   if (illegal != R_NilValue) {
 
    if (debuglevel > 0)
-     Rprintf("* setting the directions determined by parametric assumptions (step 1b).\n", i);
+     Rprintf("* setting the directions determined by parametric assumptions (step 1b).\n");
 
-    fix_wlbl(a, nnodes, nodes, R_NilValue, illegal, FALSE);
+    fix_wlbl(a, nnodes, nodes, R_NilValue, illegal, debuglevel);
 
   }/*THEN*/
 
   /* STEP 1c: fix arcs according to the whitelist and the blacklist. */
-  if (isTRUE(fix))
+  if (isTRUE(fix)) {
+
+   if (debuglevel > 0)
+     Rprintf("* setting the directions determined by whitelist and blacklist (step 1c).\n");
+
     all_fixed = fix_wlbl(a, nnodes, nodes, whitelist, blacklist, debuglevel);
 
+  }/*THEN*/
+
   if (!all_fixed) {
 
     /* STEP 2: all the arcs not part of a v-structure are now undirected. */
-    mark_vstructures(a, nodes, &nnodes, collider, debuglevel);
+    mark_vstructures(a, nodes, nnodes, collider, debuglevel);
 
     /* decide whether or not to keep moral v-structures (i.e. shielded colliders). */
     if (isTRUE(moral))
-      unmark_shielded(a, nodes, &nnodes, collider, debuglevel);
+      unmark_shielded(a, nodes, nnodes, collider, debuglevel);
 
   }/*THEN*/
 
@@ -274,10 +281,10 @@ SEXP amat;
       Rprintf("* setting the direction of more arcs (step 3, iteration %d).\n", i);
 
     /* STEP 3a: prevent the creation of cycles. */
-    changed |= prevent_cycles(a, nodes, &nnodes, collider, debuglevel);
+    changed |= prevent_cycles(a, nodes, nnodes, collider, debuglevel);
 
     /* STEP 3b: prevent the creation of additional v-structures. */
-    changed |= prevent_additional_vstructures(a, nodes, &nnodes, collider, debuglevel);
+    changed |= prevent_additional_vstructures(a, nodes, nnodes, collider, debuglevel);
 
     if (!changed) {
 
@@ -296,7 +303,7 @@ SEXP amat;
   /* STEP 4: */
 
   /* renormalize the adjacency matrix (i.e. set all elements either to 0 or 1). */
-  renormalize_amat(a, &nnodes);
+  renormalize_amat(a, nnodes);
 
   UNPROTECT(1);
 
@@ -306,8 +313,8 @@ SEXP amat;
 
 }/*CPDAG*/
 
-static void scan_graph(int *a, SEXP nodes, int *nnodes,
-    short int *collider, int debuglevel) {
+static void scan_graph(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel) {
 
  int i = 0, j = 0, counter = 0;
 
@@ -316,16 +323,16 @@ static void scan_graph(int *a, SEXP nodes, int *nnodes,
   if (debuglevel > 0)
     Rprintf("* scanning the graph (step 1).\n");
 
-  for (j = 0; j < *nnodes; j++) {
+  for (j = 0; j < nnodes; j++) {
 
     counter = 0;
 
-    for (i = 0; i < *nnodes; i++) {
+    for (i = 0; i < nnodes; i++) {
 
       /* loops are never present in a (partially) directed acyclic graph. */
       if (i == j) continue;
 
-      if ((a[CMC(i, j, *nnodes)] == PRESENT) && (a[CMC(j, i, *nnodes)] == ABSENT))
+      if ((a[CMC(i, j, nnodes)] == PRESENT) && (a[CMC(j, i, nnodes)] == ABSENT))
         counter++;
 
       /* this node has at least two parents, so it's the collider in a
@@ -347,25 +354,25 @@ static void scan_graph(int *a, SEXP nodes, int *nnodes,
 
 }/*SCAN_GRAPH*/
 
-static void mark_vstructures(int *a, SEXP nodes, int *nnodes,
-    short int *collider, int debuglevel) {
+static void mark_vstructures(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel) {
 
- int i = 0, j = 0;
+int i = 0, j = 0;
 
   /* set arcs belonging to a v-structure as FIXED. */
   if (debuglevel > 0)
     Rprintf("* marking v-structures (step 2).\n");
 
-  for (j = 0; j < *nnodes; j++) {
+  for (j = 0; j < nnodes; j++) {
 
-    /* no v-structure here, mark all arcs as undirected and skip to
-     * the next node. */
+    /* no v-structure here, mark all (non IMMUTABLE) arcs as undirected and skip
+     * to the next node. */
     if (!collider[j]) {
 
-      for (i = 0; i < *nnodes; i++) {
+      for (i = 0; i < nnodes; i++) {
 
-        if (a[CMC(i, j, *nnodes)] == PRESENT)
-          a[CMC(j, i, *nnodes)] = PRESENT;
+        if (a[CMC(i, j, nnodes)] == PRESENT)
+          a[CMC(j, i, nnodes)] = PRESENT;
 
       }/*FOR*/
 
@@ -373,40 +380,41 @@ static void mark_vstructures(int *a, SEXP nodes, int *nnodes,
 
   }/*FOR*/
 
-  for (j = 0; j < *nnodes; j++) {
+  for (j = 0; j < nnodes; j++) {
 
     /* no v-structure here, this node will be examined in step 3. */
     if (!collider[j]) continue;
 
-    for (i = 0; i < *nnodes; i++) {
+    for (i = 0; i < nnodes; i++) {
 
       /* loops are not allowed in (partially) directed graphs. */
       if (i == j) continue;
 
-      if (a[CMC(i, j, *nnodes)] == PRESENT) {
+      /* if the arc is marked as IMMUTABLE, it is always directed so nothing to do here. */
+      if (a[CMC(i, j, nnodes)] == PRESENT) {
 
-        if (a[CMC(j, i, *nnodes)] == ABSENT) {
+        if (a[CMC(j, i, nnodes)] == ABSENT) {
 
           /* this is a directed arc, it's part of a v-structure; mark it as FIXED. */
-          a[CMC(i, j, *nnodes)] = FIXED;
+          a[CMC(i, j, nnodes)] = FIXED;
 
           if (debuglevel > 0)
             Rprintf("  > fixing arc %s -> %s, it's part of a v-structure.\n", NODE(i), NODE(j));
 
         }/*THEN*/
-        else if (a[CMC(j, i, *nnodes)] == PRESENT) {
+        else if (a[CMC(j, i, nnodes)] == PRESENT) {
 
           if (collider[i]) {
 
-            /* both directions create additional v-structures, which is forbidden;
-             * fix the arc without setting a direction. */
-            a[CMC(i, j, *nnodes)] = a[CMC(j, i, *nnodes)] = FIXED;
+            /* at this point the arcs is undirected, and each endpoint is the
+             * center of a v-structure: this means that the arc was undirected
+             * in the original graph, or it would have been fixed as a directed
+             * arc in a previous step.*/
+            a[CMC(i, j, nnodes)] = a[CMC(j, i, nnodes)] = FIXED;
 
             if (debuglevel > 0)
               Rprintf("  > fixing arc %s - %s due to conflicting v-structures.\n", NODE(j), NODE(i));
 
-            warning("conflicting v-structures, the PDAG spans more than one equivalence class.");
-
           }/*THEN*/
 
         }/*THEN*/
@@ -419,24 +427,24 @@ static void mark_vstructures(int *a, SEXP nodes, int *nnodes,
 
 }/*MARK_VSTRUCTURES*/
 
-static void unmark_shielded(int *a, SEXP nodes, int *nnodes,
-    short int *collider, int debuglevel) {
+static void unmark_shielded(int *a, SEXP nodes, int nnodes, short int *collider,
+    int debuglevel) {
 
 int i = 0, j = 0, k = 0, check = FALSE;
 
   if (debuglevel > 0)
     Rprintf("* removing moral v-structures aka shielded colliders.\n");
 
-  for (i = 0; i < *nnodes; i++) {
+  for (i = 0; i < nnodes; i++) {
 
     /* that's not a collider, nothing to do.*/
     if (collider[i] == 0)
       continue;
 
-    for (j = 0; j < *nnodes; j++) {
+    for (j = 0; j < nnodes; j++) {
 
       /* this arc is not part of a v-structure. */
-      if (a[CMC(j, i, *nnodes)] != FIXED)
+      if ((a[CMC(j, i, nnodes)] != FIXED) && (a[CMC(j, i, nnodes)] != IMMUTABLE))
         continue;
 
       if (debuglevel > 0)
@@ -445,17 +453,19 @@ int i = 0, j = 0, k = 0, check = FALSE;
       /* this is set to TRUE is the arc is part of an unshielded collider. */
       check = FALSE;
 
-      for (k = 0; k < *nnodes; k++) {
+      for (k = 0; k < nnodes; k++) {
 
         /* this arc is not part of a v-structure. */
-        if ((a[CMC(k, i, *nnodes)] != FIXED) || (j == k))
+        if (((a[CMC(k, i, nnodes)] != FIXED) && (a[CMC(k, i, nnodes)] != IMMUTABLE)) || (j == k))
           continue;
 
         if (debuglevel > 0)
           Rprintf("    > considering v-structure %s -> %s <- %s.\n", NODE(j), NODE(i), NODE(k));
 
-        /* parents are not connected, that's a real v-structure. */
-        if ((a[CMC(j, k, *nnodes)] == ABSENT) && (a[CMC(k, j, *nnodes)] == ABSENT)) {
+        /* it's a real v-structure if the parents are not connected or if both
+         * arcs are marked IMMUTABLE. */
+        if (((a[CMC(j, k, nnodes)] == ABSENT) && (a[CMC(k, j, nnodes)] == ABSENT)) ||
+            ((a[CMC(j, i, nnodes)] == IMMUTABLE) && (a[CMC(k, i, nnodes)] == IMMUTABLE))) {
 
           check = TRUE;
 
@@ -476,8 +486,10 @@ int i = 0, j = 0, k = 0, check = FALSE;
         if (debuglevel > 0)
           Rprintf("  @ arc %s -> %s is not part of a v-structure.\n", NODE(j), NODE(i));
 
-        /* this arc should not be marked as FIXED and should not be directed. */
-        a[CMC(j, i, *nnodes)] = a[CMC(i, j, *nnodes)] = PRESENT;
+        /* this arc should not be marked as FIXED and should not be directed;
+         * leave it alone if marked IMMUTABLE. */
+        if (a[CMC(j, i, nnodes)] == FIXED)
+          a[CMC(j, i, nnodes)] = a[CMC(i, j, nnodes)] = PRESENT;
 
       }/*ELSE*/
 
@@ -487,27 +499,27 @@ int i = 0, j = 0, k = 0, check = FALSE;
 
 }/*UNMARK_SHIELDED*/
 
-static int prevent_cycles(int *a, SEXP nodes, int *nnodes, short int *collider,
+static int prevent_cycles(int *a, SEXP nodes, int nnodes, short int *collider,
     int debuglevel) {
 
-int i = 0, j = 0, changed = UNCHANGED, n = *nnodes;
+int i = 0, j = 0, changed = UNCHANGED;
 int *path = NULL, *scratch = NULL;
 
   /* allocate buffers for c_directed_path(). */
-  path = Calloc1D(n, sizeof(int));
-  scratch = Calloc1D(n, sizeof(int));
+  path = Calloc1D(nnodes, sizeof(int));
+  scratch = Calloc1D(nnodes, sizeof(int));
 
-  for (j = 0; j < n; j++) {
+  for (j = 0; j < nnodes; j++) {
 
-    for (i = j + 1; i < n; i++) {
+    for (i = j + 1; i < nnodes; i++) {
 
-      if ((a[CMC(i, j, n)] != PRESENT) || (a[CMC(j, i, n)] != PRESENT))
+      if ((a[CMC(i, j, nnodes)] != PRESENT) || (a[CMC(j, i, nnodes)] != PRESENT))
         continue;
 
-      if (c_directed_path(i, j, a, n, nodes, path, scratch, 0)) {
+      if (c_directed_path(i, j, a, nnodes, nodes, path, scratch, 0)) {
 
-        a[CMC(i, j, n)] = FIXED;
-        a[CMC(j, i, n)] = ABSENT;
+        a[CMC(i, j, nnodes)] = FIXED;
+        a[CMC(j, i, nnodes)] = ABSENT;
 
         if (debuglevel)
             Rprintf("  > fixing arc %s -> %s due to directed path (step 3a).\n", NODE(i), NODE(j));
@@ -515,10 +527,10 @@ int *path = NULL, *scratch = NULL;
         changed = CHANGED;
 
       }/*THEN*/
-      else if (c_directed_path(j, i, a, n, nodes, path, scratch, 0)) {
+      else if (c_directed_path(j, i, a, nnodes, nodes, path, scratch, 0)) {
 
-        a[CMC(i, j, n)] = ABSENT;
-        a[CMC(j, i, n)] = FIXED;
+        a[CMC(i, j, nnodes)] = ABSENT;
+        a[CMC(j, i, nnodes)] = FIXED;
 
         if (debuglevel)
             Rprintf("  > fixing arc %s -> %s due to directed path (step 3a).\n", NODE(j), NODE(i));
@@ -538,24 +550,25 @@ int *path = NULL, *scratch = NULL;
 
 }/*PREVENT_CYCLES*/
 
-static int prevent_additional_vstructures(int *a, SEXP nodes, int *nnodes,
+static int prevent_additional_vstructures(int *a, SEXP nodes, int nnodes,
     short int *collider, int debuglevel) {
 
-int i = 0, j = 0;
+int i = 0, j = 0, k = 0;
 short int *has_parent = NULL, *has_neighbour = NULL;
+short int shielded = FALSE, flag = FALSE;
 
-  has_parent = Calloc1D(*nnodes, sizeof(short int));
-  has_neighbour = Calloc1D(*nnodes, sizeof(short int));
+  has_parent = Calloc1D(nnodes, sizeof(short int));
+  has_neighbour = Calloc1D(nnodes, sizeof(short int));
 
-  for (j = 0; j < *nnodes; j++) {
+  for (j = 0; j < nnodes; j++) {
 
     /* check if this node has both a parent (which implies a directed, incoming
      * arc) and a neighbour (which implies an undirected incident arc).  */
-    for (i = 0; i < *nnodes; i++) {
+    for (i = 0; i < nnodes; i++) {
 
-       if (a[CMC(i, j, *nnodes)] != ABSENT) {
+       if (a[CMC(i, j, nnodes)] != ABSENT) {
 
-         if (a[CMC(j, i, *nnodes)] == PRESENT)
+         if (a[CMC(j, i, nnodes)] == PRESENT)
            has_neighbour[j] = TRUE;
          else
            has_parent[j] = TRUE;
@@ -569,58 +582,94 @@ short int *has_parent = NULL, *has_neighbour = NULL;
 
   }/*FOR*/
 
-  for (j = 0; j < *nnodes; j++) {
+  for (j = 0; j < nnodes; j++) {
 
     /* all neighbours must be changed into children to prevent the creation
      * of new v-structures.*/
-    if (has_parent[j] && has_neighbour[j]) {
+    if (!(has_parent[j] && has_neighbour[j]))
+      continue;
 
-      for (i = 0; i < *nnodes; i++) {
+    for (i = 0; i < nnodes; i++) {
 
-        if ((a[CMC(i, j, *nnodes)] != ABSENT) && (a[CMC(j, i, *nnodes)] == PRESENT)) {
+      if ((a[CMC(i, j, nnodes)] != ABSENT) && (a[CMC(j, i, nnodes)] == PRESENT)) {
 
-          if (has_parent[i]) {
+        if (has_parent[i]) {
 
-            a[CMC(i, j, *nnodes)] = FIXED;
-            a[CMC(j, i, *nnodes)] = FIXED;
+          a[CMC(i, j, nnodes)] = FIXED;
+          a[CMC(j, i, nnodes)] = FIXED;
+
+          flag = TRUE;
+
+          if (debuglevel > 0)
+            Rprintf("  > fixing arc %s - %s, both nodes have parents (step 3b).\n", NODE(j), NODE(i));
+
+        }/*THEN*/
+        else {
+
+          /* NODE(j) has at least one parent, and NODE(i) does not; if all the
+           * parents of NODE(j) are also neighbours of NODE(i) then the arc is
+           * part of a shielded collider and should be left undirected. */
+          for (k = 0, shielded = TRUE; k < nnodes; k++) {
+
+            if ((k == i) || (k == j))
+              continue;
+
+            /* NODE(k) is not a parent of NODE(j), move on. */
+            if (!((a[CMC(k, j, nnodes)] >= PRESENT) && (a[CMC(j, k, nnodes)] == ABSENT)))
+              continue;
+
+            /* if NODE(k) is a parent of NODE(j) and a parent of NODE(i), the
+             * collider is shielded. */
+            if ((a[CMC(k, i, nnodes)] >= PRESENT) && (a[CMC(i, k, nnodes)] >= PRESENT)) {
+
+              shielded = TRUE;
+
+            }/*THEN*/
+            else {
+
+              shielded = FALSE;
+              break;
+
+            }/*ELSE*/
+
+          }/*FOR*/
+
+          if (shielded) {
 
             if (debuglevel > 0)
-              Rprintf("  > fixing arc %s - %s, both nodes have parents (step 3b).\n", NODE(j), NODE(i));
+              Rprintf("  > arc %s - %s is part of a shielded collider, leave it undirected.\n", NODE(j), NODE(i));
 
           }/*THEN*/
           else {
 
-            a[CMC(i, j, *nnodes)] = ABSENT;
-            a[CMC(j, i, *nnodes)] = FIXED;
+            a[CMC(i, j, nnodes)] = ABSENT;
+            a[CMC(j, i, nnodes)] = FIXED;
+
+            flag = TRUE;
 
             if (debuglevel > 0)
               Rprintf("  > fixing arc %s -> %s, prevent v-structure (step 3b).\n", NODE(j), NODE(i));
 
-          }/*ELSE*/
+          }/*THEN*/
 
-        }/*THEN*/
+        }/*ELSE*/
 
-      }/*FOR*/
+      }/*THEN*/
 
-      Free1D(has_neighbour);
-      Free1D(has_parent);
-
-      return CHANGED;
-
-    }/*THEN*/
+    }/*FOR*/
 
   }/*FOR*/
 
   Free1D(has_neighbour);
   Free1D(has_parent);
 
-  return UNCHANGED;
+  return flag;
 
 }/*PREVENT_ADDITIONAL_VSTRUCTURES*/
 
-static void renormalize_amat(int *a, int *nnodes) {
+static void renormalize_amat(int *a, int nnodes) {
 
-  for (int i = 0; i < (*nnodes) * (*nnodes); i++)
+  for (int i = 0; i < nnodes * nnodes; i++)
     a[i] = (a[i] > 1) ? 1 : a[i];
 
 }/*RENORMALIZE_AMAT*/
